pro initial,x,u,atmos=atmos,it,time
;+
; define X grid, and initial state u.
; Read u from file atmos or a restart file
;-
@common
desc=states(/reset)
ny = n_elements(desc)
;                           ;
; From inpt file, define initial x-grid, and state variable u as a 
; function of (state, distance x)
;
x = param.xmin+dindgen(param.nx)/(param.nx-1)*(param.xmax-param.xmin)
unew = dblarr(ny,param.nx)
u=unew
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; 
; restart?
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
parami=param  ; save input param in parami
if(param.restart ne 0) then begin  ; restart
   xinput=x
   p=param.restart
   restore,'restart.sav',/verb
   a=size(u)
   nys=a(1) < ny & nxs=a(2)
   print,'Restart from time ', time, ' index = ',it
   doublit,xinput,unew  ; get full xinput array
   a=size(unew)
   nyr=a(1) & nxr=a(2)
;
; case where new calculations have a different number of points (nx ne nxr)
;
   if(nxs ne param.nx) then begin 
      message,/inf,'re-binning the x grid..'
      help,u,xinput,x,unew,nyr
      for i=0,nys-1 do unew(i,*)=interpol(reform(u(i,*)),x,xinput) 
   endif else begin 
      unew=u
   endelse
   param.restart=p
   if(param.restart eq 2) then begin 
      it=0
      time=0.
   endif
   u=unew
; clean up/reset
   param=parami
   param.nx=nxr
   param.xmin=min(xinput)
   param.xmax=max(xinput)
   desc=states()
   x=xinput
endif
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
;  read VALC type file if atmos is present
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
if(n_elements(atmos) ne 0 and param.restart eq 0) then begin ; Read from atmos file, set H parameters
   fil=param.datadir+atmos
   a=atmosrd(fil)
   linterp,a.height,a.rho,x,rho,missing=-1
   neutral=total(a.nh(0:4,*),1)
   linterp,a.height,reform(neutral),x,n1,missing=-1
   linterp,a.height,reform(a.nh(5,*)),x,nk,missing=-1
   linterp,a.height,reform(a.nne),x,nne,missing=-1
   linterp,a.height,a.rho,x,rho,missing=-1
   linterp,a.height,a.vel*1.e5,x,vel
   linterp,a.height,a.cmass*a.grav,x,ptot,missing=-1
   linterp,a.height,a.temp,x,temp
;   rho=(n1+nk)*param.mu*param.umass         ; for consistency
   bad=where(rho lt 0.,nb)
   if(nb gt 0) then begin 
      scale=exp(- (x(bad)-x(bad(0)-1))/1.e9)
      rho(bad)=rho(bad(0)-1)*scale
      n1(bad)=n1(bad(0)-1)*scale
      nk(bad)=nk(bad(0)-1)*scale
      nne(bad)=nne(bad(0)-1)*scale
      ptot(bad)=ptot(bad(0)-1)*scale
   endif
;
   u(0,*)=rho
   u(1,*)=rho*vel
   ptot=param.bconst*(n1+nk+nne)*temp  ; consistency
   fudge= 1.-.25*n1/(n1+nk) ; ion fraction of neutral
   u(2,*)=3./2.*ptot+nk*13.598*fudge*param.echarge + rho*vel*vel/2.
   u(3,*)=n1
   u(4,*)=nk
   te=(pt(u))(1,*)
   pp=(pt(u))(0,*)
   doublit,x,u
   it=0 & time=0.
   nys=5
endif
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; statistical equilibrium for He,C,N, if needed
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
desc=states()
ny = n_elements(desc)
unew=dblarr(ny,param.nx)
unew(0:nys-1,*)=u(0:nys-1,*)
u=unew
;
se,u,ue   ; get se populations
;
temp=(pt(u))[1,*]
for iel=1,n_elements(param.elements)-1 do begin ; loop over non-hydrogen elements
   el=param.elements(iel)  ; element, e.g. 6
   spec=specno(el,desc,iy,/reset)  ; find those ions to be computed
   tot=total(u(iy,*))
   if(tot eq 0.) then begin 
      message,/inf,'Filling '+el+', spectra '+$ 
              strcompress(string(min(spec))+'-'+string(max(spec) )) $
          +' with statistical eqm calculations'
      u[iy,*] =   ue[iy,*]
      totn=total(u(iy,*),1)
;      plot_oo,temp,u(iy(0),*)/totn,yran=[1.e-5,1.1],ysty=1,title='SE calculation',ps=-1
      for ii=0,n_elements(spec)-1 do oplot,temp,u(iy(ii),*)/totn,ps=-1
   endif else begin 
      message,/inf,el+' has populations already given'
   endelse      
   if(atomn(el,/num) eq 2) then begin 
      extra=u(6,*)*24.587*param.echarge + 2.*u(7,*)*4.*13.598*param.echarge 
      u(2,*)+=extra*0            ; internal energy due to He ionization
   endif
endfor
;
gravity,x
;
; boundary conditions
;
a=size(u)
ii=indgen(2)
indx=[ii,a(2)-1-ii]  ; indices of boundaries to be fixed
bcs=u(*,indx)
return
end
