pro se,u,ue
;+
; statistical equilibrium for a given state
; input:
;  u  solution vector
; output
;  ue same as solution vector but with populations set to statistical 
;  equilibrium values (coronal ionization equilibrium)
;-
;
@common
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; statistical equilibrium for He,C,N,...
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
desc=states()
ue=u
temp= reform( (pt(u))[1,*] )
into=internal(u)
for iel=0,n_elements(param.elements)-1 do begin ; loop over non-hydrogen elements
   el=param.elements(iel)  ; element, e.g. 6
   spec=specno(el,desc,iy,/reset)  ; find those ions to be computed
   totn=total(u(iy,*),1)
   if(total(totn) eq 0.) then begin 
      totn=10.d0^(abund(el)-12.)*(u(3,*)+u(4,*)) ; number wrt H
      message,/inf,'normalization of populations to Hydrogen'
   endif
   stri=seqtri(el,spec,temp,u=u)
   for j=0,n_elements(iy)-1 do ue[iy[j],*] =   stri[j,*]*totn
endfor
;
; correct u(2,*) to make the temperature the same for new values
; of internal energy 
;
inte=internal(ue)
ue(2,*)=u(2,*) + 3./2.* $ 
   (nelec(ue) -nelec(u) + total(ue(3:*,*),1) - total(u(3:*,*),1))  $  
        *param.bconst*temp + (inte-into)
return
end
