function specno, element, desc,index, reset=reset
;+
;  returns the indices of ions (1=neutral, 2=+, 3=++ etc)
;  for element from the array desc.
;
;  inputs:
;    element  - string (e.g. 'He')
;    desc - description of the states solved
;  output:
;    index (the indices of the states corresponding to the element selected)
;
;  use /reset on first call to reset/ initialize data
;  this version stores the data afer a reset call and is much
;  faster, it is called every timestep. 
;-
;
common specnos,p
;
if(n_elements(reset) ne 0) then delvarx,p
n=n_elements(desc)
nn=30
if(n_elements(p) eq 0) then begin 
   p={el:0,ions:intarr(nn),indx:intarr(nn),nions:0}
   p=replicate(p,nn)
endif
elem=atomn(element,/num)
;
;  first time through
;
k=where(p.el eq elem,nk)
if(nk eq 0) then begin 
   ionss=-1
   index=-1
   for i=3,n-1 do begin 
      el=atomn(getwrd(desc(i)),/num)
      if(el eq elem) then begin
         ion=getwrd(desc(i),1)
         if(ion eq '') then begin 
            ionss=[ionss,0]
         endif else begin 
            j=getwrd(ion,delim='+')
            ionss=[ionss,fix(j)]
         endelse
         index=[index,i]
      endif
   endfor
   q=where(index ge 0)
   index=index(q)
   q=where(ionss ge 0)
   spnos=ionss(q)+1
   nq=n_elements(spnos)
   p(elem).el=elem
   p(elem).ions(0:nq-1)=spnos
   p(elem).indx(0:nq-1)=index
   p(elem).nions=nq
endif
;
; return data
;
nq=p(elem).nions
index=(p(elem).indx)[0:nq-1]
return,(p(elem).ions)[0:nq-1]
end
