pro uplot,x,u,t,ps=ps,four_panels=four_panels,ratio=ratio,equilibrium=equilibrium,element=element,$
          window=window
;+
;  plots state variables at a given time t, as a function of X
;-
@common
;
desc=states()
i=n_elements(t)-1
a=size(u) & ny=a(1) & nx=a(2)
j=1+indgen(nx-2)
v=u(*,j)
if(n_elements(ratio) ne 0 or n_elements(equilibrium) ne 0) then begin 
   se,v,ve
   if (n_elements(equilibrium) ne 0) then v=ve
endif
;
xp=x(j)/1.e8
;
pold=!p
if(n_elements(window) eq 0) then window=14
if(n_elements(four_panels) ne 0) then !p.multi=[0,2,2] else !p.multi=[0,3,2] 

if(n_elements(ps) eq 0) then begin 
   wset,window
   !p.charsize=1.8
endif else begin 
   !p.charsize=.8
endelse
st=string(t,format='(f8.2)')+'s'
rho='!4q!3'

plot_io,xp,v(0,*),title='t='+st,ytitle=rho+' g cm!u-3!n',ps=3,xsty=1,yr=[1.e-16,1.e-11],ysty=1,xr=xr,$
        xtitle='Mm'

plot,xp,v(1,*)/v(0,*)/1.e5,ytitle='u km s!u-1!n',yran=[-30,30]*6,ps=3,xsty=1,xr=xr,ysty=1
oplot,xp,csound(v)/1.e5
oplot,xp,-csound(v)/1.e5
oplot,xp,xp*0.
temp=(pt(v))[1,*]
leg=['Csound','Velocity']
legend,/bottom,/center,leg,lines=findgen(n_elements(leg)),charsize=0.5*!p.charsize


plot_io,xp,temp,ps=3,xsty=1,yr=[1000.,2.5e6],ysty=1,xr=xr,ytitle='T K'
pp=(pt(v))(0,*)

bg='n(' & nd=')'
bg='' & nd=''
if(n_elements(four_panels) eq 0) then  begin
   tot=v(2,*)
   plot_io,xp,tot/v(0,*),ytitle='E/'+rho+' erg g!u-1!n',xr=xr,xsty=1,$
           xtitle='Mm'          ; energy per gram
   ke=0.5*v(1,*)*v(1,*)/v(0,*)
   thermal=3./2.*(pt(v))(0,*)
   oplot,xp,ke/v(0,*),ps=3
   internal=(tot-thermal-ke)
   oplot,xp,internal/v(0,*),ps=1
   leg=['Total','KE','Internal']
   legend,/bottom,/center,leg,psym=[0,3,1],charsize=0.5*!p.charsize,num=4,pspacing=0.5
   plot_io,xp,nelec(v),ytitle='n!de!n  n('+desc(4)+') cm!u-3!n',xr=xr,xsty=1
   oplot,xp,v(4,*),lines=1
   leg=['n!de!n',bg+desc(4)+nd]
   legend,/top,/center,leg,lines=findgen(n_elements(leg)),charsize=0.5*!p.charsize
endif
;
y=v(3,*)
yran=[1.e0,1.e12]
ytitle='densities cm!u-3!n'
if(n_elements(equilibrium) ne 0) then ytitle='CNO... eqm '+ ytitle
if(n_elements(ratio) ne 0) then begin 
   y = v(3,*)/ve(3,*)
   yran=[1.e-6,1.e6]
   ytitle='ratios n/n(eq)'
endif

plot_io,xp,v(3,*),lines=0,yran=yran,ytitle=ytitle,xr=[1.5,3],xsty=1,ysty=1
leg=[bg+desc(3)+nd]
lines=0
linearr=0
elold=atomn(getwrd(desc(3)),/num)
;
nelem=0
if(n_elements(element) ne 0) then nelem=atomn(element,/num)
for ii=4,ny-1 do begin 
   el=atomn(getwrd(desc(ii)),/num)
   if(nelem eq 0 or el eq nelem) then begin 
      ll=specno(el,desc,index)
      if(elold ne el) then begin 
         lines=lines+1
         linearr=[linearr,lines]
         leg=[leg,bg+getwrd(desc(ii))+nd]
         elold=el
      endif
;
;  get those with significant populations
;
      tion=total(v(index,*),1)
      ok=where(v(ii,*)/tion gt 1.e-4 and xp gt !x.crange(0) and xp lt !x.crange(1),count)
      if(count gt 0) then begin 
         y=v(ii,ok)
         if(n_elements(ratio) ne 0) then y = y/ve(ii,ok)
         oplot,xp(ok),y, lines=lines
;
; spectrum labels
;
         ss=strtrim(getwrd(desc(ii),1),2)
         if(ss eq '') then ss='0'
         nnn= (count/5) > 1
         
         for jj=0,n_elements(ok)-1,nnn do begin 
            yy=y(jj)
            if(yy gt 10.^!y.crange(0) and yy lt 10.^!y.crange(1)) then $
               xyouts,xp(ok(jj)),yy,ss,size=.9
         endfor
      endif
   endif ; element loop
endfor
nn=n_elements(leg)
size=!p.charsize/1.4/(1.+nn/20.)
legend,/top,/right,leg,lines=linearr,charsize=size
;
!p=pold
return
end
